@@ -2,7 +2,7 @@
 import inspect
 
 import rope.base.evaluate
-from rope.base import pynames, pyobjects, arguments, utils
+from rope.base import pynames, pyobjects, arguments, utils, ast
 
 
 class BuiltinModule(pyobjects.AbstractModule):
@@ -32,7 +32,7 @@ class BuiltinModule(pyobjects.AbstractModule):
         result.update(self.initial)
         if self.pycore is not None:
             submodules = self.pycore._builtin_submodules(self.name)
-            for name, module in list(submodules.items()):
+            for name, module in submodules.items():
                 result[name] = rope.base.builtins.BuiltinName(module)
         return result
 
@@ -110,6 +110,9 @@ class BuiltinUnknown(_BuiltinElement, pyobjects.PyObject):
         self.builtin = builtin
         self.type = pyobjects.get_unknown()
 
+    def get_name(self):
+        return getattr(type(self.builtin), '__name__', None)
+
     @utils.saveit
     def get_attributes(self):
         return _object_attributes(self.builtin, self)
@@ -120,8 +123,6 @@ def _object_attributes(obj, parent):
     for name in dir(obj):
         if name == 'None':
             continue
-        if not hasattr(obj, name):
-            continue
         child = getattr(obj, name)
         pyobject = None
         if inspect.isclass(child):
@@ -257,8 +258,6 @@ class List(BuiltinClass):
         # Getting methods
         collector('__getitem__', function=self._list_get)
         collector('pop', function=self._list_get)
-        #collector('getitem', function=self._self_get)
-        #collector('__getslice__', function=self._self_get)
 
         super(List, self).__init__(list, collector.attributes)
 
@@ -281,15 +280,14 @@ class List(BuiltinClass):
             context.save_per_name(holding)
 
     def _list_get(self, context):
-        args = context.get_arguments(['self', 'key'])
         if self.holding is not None:
-            if len(args) > 1 and args[1] is not None:
-                key = args[1]
-                if key.get_type() == builtins['slice'].get_object():
-                    return get_list(self.holding)
+            args = context.get_arguments(['self', 'key'])
+            if len(args) > 1 and args[1] is not None \
+                and args[1].get_type() == builtins['slice'].get_object():
+                return get_list(self.holding)
             return self.holding
         return context.get_per_name()
-        
+
     def _iterator_get(self, context):
         return get_iterator(self._list_get(context))
 
@@ -498,25 +496,10 @@ class Str(BuiltinClass):
     def get_doc(self):
         return str.__doc__
 
+
 get_str = _create_builtin_getter(Str)
 get_str_type = _create_builtin_type_getter(Str)
 
-class Int(BuiltinClass):
-    def __init__(self):
-        self_object = pyobjects.PyObject(self)
-        collector = _AttributeCollector(int)
-        self_methods = ['bit_length', 'conjugate', 'denominator', 'imag', 'numerator', 'real']
-
-        for method in self_methods:
-            collector(method, self_object)
-
-        super(Int, self).__init__(int, collector.attributes)
-
-    def get_doc(self):
-        return int.__doc__
-
-get_int = _create_builtin_getter(Int)
-get_int_type = _create_builtin_type_getter(Int)
 
 class BuiltinName(pynames.PyName):
 
@@ -620,6 +603,7 @@ class Lambda(pyobjects.AbstractFunction):
     def __init__(self, node, scope):
         super(Lambda, self).__init__()
         self.node = node
+        self.arguments = node.args
         self.scope = scope
 
     def get_returned_object(self, args):
@@ -629,9 +613,37 @@ class Lambda(pyobjects.AbstractFunction):
         else:
             return pyobjects.get_unknown()
 
-    def get_pattributes(self):
+    def get_module(self):
+        return self.parent.get_module()
+
+    def get_scope(self):
+        return self.scope
+
+    def get_kind(self):
+        return 'lambda'
+
+    def get_ast(self):
+        return self.node
+
+    def get_attributes(self):
         return {}
 
+    def get_name(self):
+        return  'lambda'
+
+    def get_param_names(self, special_args=True):
+        result = [node.arg for node in self.arguments.args
+                  if isinstance(node, ast.arg)]
+        if self.arguments.vararg:
+            result.append('*' + self.arguments.vararg)
+        if self.arguments.kwarg:
+            result.append('**' + self.arguments.kwarg)
+        return result
+
+    @property
+    def parent(self):
+        return self.scope.pyobject
+
 
 class BuiltinObject(BuiltinClass):
 
@@ -651,8 +663,10 @@ def _infer_sequence_for_pyname(pyname):
     seq = pyname.get_object()
     args = arguments.ObjectArguments([pyname])
     if '__iter__' in seq:
-        iter = seq['__iter__'].get_object().\
-               get_returned_object(args)
+        obj = seq['__iter__'].get_object()
+        if not isinstance(obj, pyobjects.AbstractFunction):
+            return None
+        iter = obj.get_returned_object(args)
         if iter is not None and 'next' in iter:
             holding = iter['next'].get_object().\
                       get_returned_object(args)
@@ -732,7 +746,6 @@ _initial_builtins = {
     'tuple': BuiltinName(get_tuple_type()),
     'set': BuiltinName(get_set_type()),
     'str': BuiltinName(get_str_type()),
-    'int': BuiltinName(get_int_type()),
     'file': BuiltinName(get_file_type()),
     'open': BuiltinName(get_file_type()),
     'unicode': BuiltinName(get_str_type()),
@@ -746,7 +759,7 @@ _initial_builtins = {
     'object': BuiltinName(BuiltinObject()),
     'type': BuiltinName(BuiltinType()),
     'iter': BuiltinName(BuiltinFunction(function=_iter_function, builtin=iter)),
-    'raw_input': BuiltinName(BuiltinFunction(function=_input_function, builtin=input)),
+    'input': BuiltinName(BuiltinFunction(function=_input_function, builtin=input)),
     }
 
 builtins = BuiltinModule('builtins', initial=_initial_builtins)
