@@ -63,8 +63,7 @@ class PyFunction(pyobjects.PyFunction):
             return self.parameter_pyobjects.get()[index]
 
     def get_returned_object(self, args):
-        ret = self.returned.get(args)
-        return ret
+        return self.returned.get(args)
 
     def get_name(self):
         return self.get_ast().name
@@ -149,9 +148,11 @@ class PyModule(pyobjects.PyModule):
                  resource=None, force_errors=False):
         ignore = pycore.project.prefs.get('ignore_syntax_errors', False)
         syntax_errors = force_errors or not ignore
+        self.has_errors = False
         try:
             source, node = self._init_source(pycore, source, resource)
         except exceptions.ModuleSyntaxError:
+            self.has_errors = True
             if syntax_errors:
                 raise
             else:
@@ -222,11 +223,11 @@ class PyPackage(pyobjects.PyPackage):
         result = {}
         modname = self.pycore.modname(self.resource)
         extension_submodules = self.pycore._builtin_submodules(modname)
-        for name, module in list(extension_submodules.items()):
+        for name, module in extension_submodules.items():
             result[name] = rope.base.builtins.BuiltinName(module)
         if self.resource is None:
             return result
-        for name, resource in list(self._get_child_resources().items()):
+        for name, resource in self._get_child_resources().items():
             result[name] = pynames.ImportedModule(self, resource=resource)
         return result
 
@@ -366,12 +367,14 @@ class _ScopeVisitor(object):
         if not isinstance(targets, str):
             names = astutils.get_name_levels(targets)
             for name, levels in names:
-                assignment = pynames.AssignmentValue(assigned, levels, evaluation, eval_type)
+                assignment = pynames.AssignmentValue(assigned, levels,
+                                                     evaluation, eval_type)
                 self._assigned(name, assignment)
         else:
-            assignment = pynames.AssignmentValue(assigned, [], evaluation, eval_type)
+            assignment = pynames.AssignmentValue(assigned, [],
+                                                 evaluation, eval_type)
             self._assigned(targets, assignment)
-        return result 
+        return result
 
     def _With(self, node):
         if node.optional_vars:
