@@ -108,7 +108,7 @@ class DynamicOITest(unittest.TestCase):
         pymod = self.pycore.resource_to_pyobject(mod)
         self.assertEquals(pymod['AClass'].get_object(),
                           pymod['a_var'].get_object())
-
+    
     def test_nested_classes(self):
         mod = testutils.create_module(self.project, 'mod')
         code = 'def a_func():\n    class AClass(object):\n' \
@@ -121,6 +121,7 @@ class DynamicOITest(unittest.TestCase):
         self.assertEquals(pyscope.get_scopes()[0]['AClass'].get_object(),
                           pyscope['a_var'].get_object())
 
+    
     def test_function_argument_dti2(self):
         mod = testutils.create_module(self.project, 'mod')
         code = 'def a_func(arg, a_builtin_type):\n    pass\n' \
@@ -182,7 +183,7 @@ class DynamicOITest(unittest.TestCase):
         mod = testutils.create_module(self.project, 'mod')
         code = 'class C(object):\n    pass\n' \
                'def a_func(arg):\n    return eval("arg")\n' \
-               'a_var = a_func({C(): 1}).keys()[0]\n'
+               'a_var = list(a_func({C(): 1}).keys())[0]\n'
         mod.write(code)
         self.pycore.run_module(mod).wait_process()
         pymod = self.pycore.resource_to_pyobject(mod)
@@ -213,7 +214,6 @@ class DynamicOITest(unittest.TestCase):
         self.pycore.run_module(mod).wait_process()
         pymod = self.pycore.resource_to_pyobject(mod)
         a_var = pymod['a_var'].get_object()
-        print(a_var.get_type())
         self.assertTrue(isinstance(a_var.get_type(), rope.base.builtins.Str))
 
     def test_textual_transformations(self):
@@ -249,7 +249,7 @@ class DynamicOITest(unittest.TestCase):
         b_var = pymod['b'].get_object()
         self.assertEquals(c1_class, a_var.get_type())
         self.assertEquals(c2_class, b_var.get_type())
-    
+
     def test_a_function_with_different_returns(self):
         mod = testutils.create_module(self.project, 'mod')
         code = 'class C1(object):\n    pass\nclass C2(object):\n    pass\n' \
@@ -264,11 +264,11 @@ class DynamicOITest(unittest.TestCase):
         b_var = pymod['b'].get_object()
         self.assertEquals(c1_class, a_var.get_type())
         self.assertEquals(c2_class, b_var.get_type())
- 
+
     def test_a_function_with_different_returns2(self):
         mod = testutils.create_module(self.project, 'mod')
         code = 'class C1(object):\n    pass\nclass C2(object):\n    pass\n' \
-               'def a_func(p):\n    print(p)\n    if p == C1:\n        print("ret c1")\n        return C1()\n' \
+               'def a_func(p):\n    if p == C1:\n        return C1()\n' \
                '    else:\n        return C2()\n' \
                'a = a_func(C1)\nb = a_func(C2)\n'
         mod.write(code)
@@ -278,8 +278,6 @@ class DynamicOITest(unittest.TestCase):
         c2_class = pymod['C2'].get_object()
         a_var = pymod['a'].get_object()
         b_var = pymod['b'].get_object()
-        print(a_var.get_type().get_name())
-        print(b_var.get_type().get_name())
         self.assertEquals(c1_class, a_var.get_type())
         self.assertEquals(c2_class, b_var.get_type())
 
@@ -340,6 +338,7 @@ class DynamicOITest(unittest.TestCase):
         pymod2 = self.pycore.resource_to_pyobject(mod2)
         self.assertEquals(pymod2['C'].get_object(),
                           pymod['a_var'].get_object())
+    
 
 class NewStaticOITest(unittest.TestCase):
 
