@@ -15,7 +15,7 @@ class BuiltinTypesTest(unittest.TestCase):
     def tearDown(self):
         testutils.remove_project(self.project)
         super(BuiltinTypesTest, self).tearDown()
-
+    
     def test_simple_case(self):
         self.mod.write('l = []\n')
         pymod = self.pycore.resource_to_pyobject(self.mod)
@@ -42,14 +42,13 @@ class BuiltinTypesTest(unittest.TestCase):
         c_class = pymod['C'].get_object()
         a_var = pymod['a_var'].get_object()
         self.assertEquals(c_class, a_var.get_type())
-
+    
     def test_get_items_from_slices(self):
         self.mod.write('class C(object):\n    pass\nl = [C()]\na_var = l[:].pop()\n')
         pymod = self.pycore.resource_to_pyobject(self.mod)
         c_class = pymod['C'].get_object()
         a_var = pymod['a_var'].get_object()
         self.assertEquals(c_class, a_var.get_type())
-
     def test_simple_for_loops(self):
         self.mod.write('class C(object):\n    pass\nl = [C()]\n'
                        'for c in l:\n    a_var = c\n')
@@ -271,6 +270,15 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEquals(pyobjects.get_base_type('Function'),
                           l_var.get_type())
 
+    def test_lambda_function_definition(self):
+        self.mod.write('l = lambda x, y = 2, *a, **b: x + y\n')
+        pymod = self.pycore.resource_to_pyobject(self.mod)
+        l_var = pymod['l'].get_object()
+        self.assertTrue(l_var.get_name() is not None)
+        self.assertEquals(len(l_var.get_param_names()), 4)
+        self.assertEquals((pymod, 1),
+                          pymod['l'].get_definition_location())
+
     def test_lambdas_that_return_unknown(self):
         self.mod.write('a_var = (lambda: None)()\n')
         pymod = self.pycore.resource_to_pyobject(self.mod)
@@ -314,7 +322,7 @@ class BuiltinTypesTest(unittest.TestCase):
         a_var = pymod['a'].get_object()
         b_var = pymod['b'].get_object()
         self.assertEquals(c1_class, a_var.get_type())
-    
+
     def test_enumerate_builtin_function(self):
         self.mod.write('class C(object):\n    pass\nl = [C()]\n'
                        'for i, x in enumerate(l):\n    a_var = x\n')
@@ -406,6 +414,21 @@ class BuiltinTypesTest(unittest.TestCase):
         self.assertEquals(builtins.builtins['int'].get_object(),
                           pymod['l'].get_object().get_type())
 
+    def test_binary_or_left_value_unknown(self):
+        code = 'var = (asdsd or 3)\n'
+        pymod = self.pycore.get_string_module(code)
+        self.assertEquals(builtins.builtins['int'].get_object(),
+                          pymod['var'].get_object().get_type())
+
+    def test_unknown_return_object(self):
+        src = 'import sys\n' \
+              'def foo():\n' \
+              '  res = set(sys.builtin_module_names)\n' \
+              '  if foo: res.add(bar)\n'
+        self.project.prefs['import_dynload_stdmods'] = True
+        self.mod.write(src)
+        self.project.pycore.analyze_module(self.mod)
+
 class BuiltinModulesTest(unittest.TestCase):
 
     def setUp(self):
@@ -445,6 +468,7 @@ class BuiltinModulesTest(unittest.TestCase):
         invalid = pymod['invalid'].get_object()
         self.assertTrue('sub' in invalid)
 
+
 def suite():
     result = unittest.TestSuite()
     result.addTests(unittest.makeSuite(BuiltinTypesTest))
