@@ -23,16 +23,16 @@ class CodeAssistTest(unittest.TestCase):
         if offset is None:
             offset = len(code)
         return code_assist(self.project, code, offset,  **args)
-    
+
     def test_simple_assist(self):
         self._assist('', 0)
-    
-    def assert_completion_in_result(self, name, kind, result, type=None):
+
+    def assert_completion_in_result(self, name, scope, result, type=None):
         for proposal in result:
             if proposal.name == name:
-                self.assertEqual(kind, proposal.scope,
-                        "proposal <%s> has wrong kind, expected " \
-                        "%r, got %r" % (name, kind, proposal.scope))
+                self.assertEqual(scope, proposal.scope,
+                        "proposal <%s> has wrong scope, expected " \
+                        "%r, got %r" % (name, scope, proposal.scope))
                 if type is not None:
                     self.assertEqual(type, proposal.type,
                             "proposal <%s> has wrong type, expected " \
@@ -40,9 +40,9 @@ class CodeAssistTest(unittest.TestCase):
                 return
         self.fail('completion <%s> not proposed' % name)
 
-    def assert_completion_not_in_result(self, name, kind, result):
+    def assert_completion_not_in_result(self, name, scope, result):
         for proposal in result:
-            if proposal.name == name and proposal.scope == kind:
+            if proposal.name == name and proposal.scope == scope:
                 self.fail('completion <%s> was proposed' % name)
 
     def test_completing_global_variables(self):
@@ -391,7 +391,7 @@ class CodeAssistTest(unittest.TestCase):
         self.assertEquals((None, 2), result)
 
     def test_if_scopes_in_other_scopes_for_get_definition_location(self):
-        code = 'def f(a_var):\n    pass\na_var = 10\nif True:\n    print(a_var)\n'
+        code = 'def f(a_var):\n    pass\na_var = 10\nif True:\n    print a_var\n'
         result = get_definition_location(self.project, code, len(code) - 3)
         self.assertEquals((None, 3), result)
 
@@ -453,14 +453,14 @@ class CodeAssistTest(unittest.TestCase):
         proposals = sorted_proposals(self._assist(code))
         self.assertEquals('my_func', proposals[0].name)
         self.assertEquals('_my_func', proposals[1].name)
-    
-    def test_proposals_sorter_and_kind_prefs(self):
+
+    def test_proposals_sorter_and_scope_prefs(self):
         code = 'my_global_var = 1\n' \
                'def func(self):\n' \
                '    my_local_var = 2\n' \
                '    my_'
         result = self._assist(code)
-        proposals = sorted_proposals(result, kindpref=['global', 'local'])
+        proposals = sorted_proposals(result, scopepref=['global', 'local'])
         self.assertEquals('my_global_var', proposals[0].name)
         self.assertEquals('my_local_var', proposals[1].name)
 
@@ -719,6 +719,17 @@ class CodeAssistTest(unittest.TestCase):
         doc = get_calltip(self.project, src, src.rindex('f'), remove_self=True)
         self.assertEquals('C.f(p1)', doc)
 
+    def test_lambda_calltip(self):
+        src = 'foo = lambda x, y=1: None\n' \
+              'foo()'
+        doc = get_calltip(self.project, src, src.rindex('f'))
+        self.assertEqual(doc, 'lambda(x, y)')
+
+    def test_keyword_before_parens(self):
+        code = 'if (1).:\n pass'
+        result = self._assist(code, offset=len('if (1).'))
+        self.assertTrue(result)
+
     # TESTING PROPOSAL'S KINDS AND TYPES.
     # SEE RELATION MATRIX IN `CompletionProposal`'s DOCSTRING
 
@@ -830,7 +841,8 @@ class CodeAssistTest(unittest.TestCase):
         for expected in ('abc=', 'aloha=', 'alpha=', 'amigo='):
             self.assert_completion_in_result(expected, 'parameter_keyword',
                                              result, type=None)
-    
+
+
 class CodeAssistInProjectsTest(unittest.TestCase):
 
     def setUp(self):
@@ -854,15 +866,15 @@ class CodeAssistInProjectsTest(unittest.TestCase):
     def _assist(self, code, resource=None, **kwds):
         return code_assist(self.project, code, len(code), resource, **kwds)
 
-    def assert_completion_in_result(self, name, kind, result):
+    def assert_completion_in_result(self, name, scope, result):
         for proposal in result:
-            if proposal.name == name and proposal.scope == kind:
+            if proposal.name == name and proposal.scope == scope:
                 return
         self.fail('completion <%s> not proposed' % name)
 
-    def assert_completion_not_in_result(self, name, kind, result):
+    def assert_completion_not_in_result(self, name, scope, result):
         for proposal in result:
-            if proposal.name == name and proposal.scope == kind:
+            if proposal.name == name and proposal.scope == scope:
                 self.fail('completion <%s> was proposed' % name)
 
     def test_simple_import(self):
@@ -893,7 +905,7 @@ class CodeAssistInProjectsTest(unittest.TestCase):
     def test_from_import_only_imports_imported(self):
         code = 'from samplemod import sample_func\nSample'
         result = self._assist(code)
-        self.assert_completion_not_in_result('SampleClass', 'imported', result)
+        self.assert_completion_not_in_result('SampleClass', 'global', result)
 
     def test_from_import_star(self):
         code = 'from samplemod import *\nSample'
