@@ -388,7 +388,7 @@ class ProjectTest(unittest.TestCase):
         file = open(sample_file.real_path, 'wb')
         file.write(contents)
         file.close()
-        self.assertEquals(contents, sample_file.read().encode("latin-1"))
+        self.assertEquals(contents, sample_file.read().encode('latin-1'))
 
     def test_read_bytes(self):
         sample_file = self.project.root.create_file('my_file.txt')
