@@ -278,7 +278,6 @@ class PyCoreTest(unittest.TestCase):
                                source_folders=['pkg1/src2'])
         self.assertEqual(self.project.pycore.find_module('lost'), lost)
 
-    
     def test_getting_empty_source_folders(self):
         self.assertEquals([], self.pycore.get_source_folders())
 
@@ -647,6 +646,7 @@ class PyCoreTest(unittest.TestCase):
         self.assertEquals(pymod1['var1'].get_object(),
                           pymod1['var2'].get_object())
 
+
 class PyCoreInProjectsTest(unittest.TestCase):
 
     def setUp(self):
@@ -998,6 +998,18 @@ class PyCoreInProjectsTest(unittest.TestCase):
         mod1.write('class A(object):\n    def func2(self):\n        pass\n')
         self.assertTrue('func2' in b_class)
 
+    def test_caching_pymodule_with_syntax_errors(self):
+        self.project.prefs['ignore_syntax_errors'] = True
+        self.project.prefs['automatic_soa'] = True
+        self.project.pycore._init_automatic_soa()
+        source = 'import sys\nab cd'
+        mod = testutils.create_module(self.project, 'mod')
+        mod.write(source)
+        from rope.contrib import fixsyntax
+        fixer = fixsyntax.FixSyntax(self.project.pycore, source, mod, 10)
+        pymodule = fixer.get_pymodule()
+        self.assertTrue(pymodule.source_code.startswith('import sys\npass\n'))
+
 
 class TextChangeDetectorTest(unittest.TestCase):
 
